@@ -3,7 +3,7 @@ package SlapbirdAPM::Agent::Dancer2;
 use strict;
 use warnings;
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 1;
 
@@ -13,9 +13,9 @@ our $VERSION = '0.003';
 
 =head1 NAME
 
-SlapbirdAPM::Agent::Mojo
+SlapbirdAPM::Agent::Dancer2
 
-The L<SlapbirdAPM|https://www.slapbirdapm.com> user-agent for L<Mojolicious> applications.
+The L<SlapbirdAPM|https://www.slapbirdapm.com> user-agent for L<Dancer2> applications.
 
 =head1 SYNOPSIS
 
